@@ -138,6 +138,19 @@ def connect_psycopg2(host, port=None, username=None, password=None, database=Non
         import psycopg2.extensions
     except ImportError:
         return
+    # see: https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-PARAMKEYWORDS
+    allowed_dsn = {
+        #"host", "hostaddr", "port", "dbname", "user", "password", "passfile",
+        "channel_binding", "connect_timeout", "client_encoding",
+        "options", "application_name", "fallback_application_name",
+        "keepalives", "keepalives_idle", "keepalives_interval",
+        "keepalives_count",
+        "tcp_user_timeout", "tty", "replication", "gssencmode", "sslmode", "requiressl",
+        "sslcompression", "sslcert", "sslkey", "sslpassword", "sslrootcert", "sslcrl", "sslcrldir",
+        "sslcni", "requirepeer", "ssl_min_protocol_version", "ssl_max_protocol_version",
+        "krbsrvname", "gsslib", "service", "target_session_attrs"
+    }
+    kwargs = {k: v for k, v in kwargs.items() if k in allowed_dsn}
     dsn_parts = {"host": host, "port": port or 5432, "dbname": database or "postgres"}
     if username:
         dsn_parts["user"] = username
