@@ -7,7 +7,7 @@ import pandas
 import shutil
 
 import dslibrary
-from dslibrary.front import PARAMS_ALIAS, METRICS_ALIAS
+from dslibrary.front import PARAMS_ALIAS, METRICS_ALIAS, THREAD_SPEC
 from dslibrary.run_models import ModelRunner
 from tests.t_utils import reset_env
 
@@ -18,16 +18,52 @@ class TestRunMethod(unittest.TestCase):
     hyper-parameter tuning.
     """
 
-    def test_run_method__intended_approach(self):
+    def test_run_method__dsl_as_parameter(self):
         """
         A dslibrary instance is passed to the code you want to run.
         """
         def my_model(dsl):
-            assert dsl.get_parameter("x") == 123
+            self.assertEqual(123, dsl.get_parameter("x"))
         runner = ModelRunner()
         runner.set_parameter("x", 123)
         runner.run_method(my_model)
 
+    def test_run_method__thread_local(self):
+        """
+        Override spec for current thread.
+        """
+        def my_model(x=1):
+            spec = THREAD_SPEC.value
+            self.assertEqual(x, 123)
+            self.assertEqual({"x": 123}, spec["parameters"])
+            self.assertEqual(123, dslibrary.get_parameter("x"))
+        runner = ModelRunner()
+        runner.set_parameter("x", 123)
+        assert not hasattr(THREAD_SPEC, "value")
+        runner.run_method(my_model)
+        assert not hasattr(THREAD_SPEC, "value")
+
+    def test_run_method__thread_local__mult(self):
+        """
+        Verify the point of thread-local configuration: thread safety on multiple concurrent calls.
+        """
+        import threading
+        log = []
+        def my_model(x=1):
+            log.append(x)
+        threads = []
+        for x in range(100):
+            def bg(x):
+                runner = ModelRunner()
+                runner.set_parameter("x", x)
+                runner.run_method(my_model)
+            t = threading.Thread(target=bg, args=(x,))
+            threads.append(t)
+            t.start()
+        for t in threads:
+            t.join()
+        self.assertEqual(list(range(100)), list(sorted(log)))
+
     def test_run_method__alternate_approach(self):
         """
         The model can also call dslibrary.instance()
