@@ -87,3 +87,15 @@ class TestConnect(unittest.TestCase):
         with mock.patch("psycopg2.connect", conn):
             c = dslibrary.get_sql_connection('postgres://HOST:5432/postgres', password="xyz", **{'username': 'postgres'})
             assert isinstance(c, MyPg)
+
+    def test_connect_psycopg2_valid_dsn(self):
+        class MyPg(object):
+            def set_isolation_level(self, n):
+                pass
+        def conn(**kwargs):
+            self.assertEqual(kwargs, {'dsn': 'dbname=db1 host=host password=p port=1234 user=u', 'service': 's1'})
+            return MyPg()
+        with mock.patch("psycopg2.connect", conn):
+            connect_psycopg2(host="host", port=1234, username="u", password="p", database="db1", a=123, z="def",
+                             service="s1")
+
