@@ -181,3 +181,5 @@ class TestDBConn(unittest.TestCase):
         self.assertEqual(sql_enquote_id(("x", "y")), 'x.y')
         self.assertEqual(sql_enquote_id(("x", "y z")), 'x."y z"')
         self.assertEqual(sql_enquote_id("x", always=True, mode="mysql"), '`x`')
+        self.assertEqual(sql_enquote_id("AbC", "mysql"), 'AbC')
+        self.assertEqual(sql_enquote_id("AbC", "postgres"), '"AbC"')
